@@ -34,100 +34,99 @@ using namespace Wacom;
 
 namespace Wacom
 {
-    class AreaSelectionWidgetPrivate
+class AreaSelectionWidgetPrivate
+{
+public:
+    AreaSelectionWidgetPrivate()
     {
-        public:
-            AreaSelectionWidgetPrivate() {
-                // set some reasonable default values
-                dragMode                     = AreaSelectionWidget::DragMode::DragNone;
-                widgetTargetSize             = QSize(400,400);
-                outOfBoundsMargin            = 0.;
-                outOfBoundsVirtualAreaMargin = 0.;
-                outOfBoundsDisplayAreaMargin = 0.;
-                scaleFactor                  = .1; // prevent division by zero.
+        // set some reasonable default values
+        dragMode = AreaSelectionWidget::DragMode::DragNone;
+        widgetTargetSize = QSize(400, 400);
+        outOfBoundsMargin = 0.;
+        outOfBoundsVirtualAreaMargin = 0.;
+        outOfBoundsDisplayAreaMargin = 0.;
+        scaleFactor = .1; // prevent division by zero.
 
-                drawAreaCaption              = true;
-                drawSelectionCaption         = true;
+        drawAreaCaption = true;
+        drawSelectionCaption = true;
 
-                fontCaptions                 = QFont(QLatin1String("sans"), 10);
+        fontCaptions = QFont(QLatin1String("sans"), 10);
 
-                // TODO: set colors based on UI theme
-                colorDisplayAreaBrush        = QColor(Qt::lightGray);
-                colorDisplayAreaPen          = QColor(Qt::black);
-                colorDisplayAreaText         = QColor(Qt::black);
+        // TODO: set colors based on UI theme
+        colorDisplayAreaBrush = QColor(Qt::lightGray);
+        colorDisplayAreaPen = QColor(Qt::black);
+        colorDisplayAreaText = QColor(Qt::black);
 
-                colorSelectedAreaBrush       = QColor("#9EAEBF");
-                colorSelectedAreaPen         = QColor("#555E67");
-                colorSelectedAreaText        = QColor(colorSelectedAreaPen);
+        colorSelectedAreaBrush = QColor("#9EAEBF");
+        colorSelectedAreaPen = QColor("#555E67");
+        colorSelectedAreaText = QColor(colorSelectedAreaPen);
 
-                colorDragHandles             = QColor(colorSelectedAreaPen);
-            }
+        colorDragHandles = QColor(colorSelectedAreaPen);
+    }
 
-            static const qreal   DISPLAY_AREA_EXTRA_MARGIN; //!< An extra margin around the display area which is not taken into account for out of bounds calculations.
-            static const qreal   DRAG_HANDLE_SIZE;          //!< The size of the drag handles.
+    static const qreal DISPLAY_AREA_EXTRA_MARGIN; //!< An extra margin around the display area which is not taken into account for out of bounds calculations.
+    static const qreal DRAG_HANDLE_SIZE; //!< The size of the drag handles.
 
-            bool                 drawAreaCaption;        //!< Determines if the caption of the display areas should be drawn.
-            bool                 drawSelectionCaption;   //!< Determines if the caption of the selected area should be drawn.
+    bool drawAreaCaption; //!< Determines if the caption of the display areas should be drawn.
+    bool drawSelectionCaption; //!< Determines if the caption of the selected area should be drawn.
 
-            QColor               colorDisplayAreaPen;    //!< The outline color of the display areas.
-            QColor               colorDisplayAreaBrush;  //!< The fill colors of the display areas.
-            QColor               colorDisplayAreaText;   //!< The text color of the display areas.
+    QColor colorDisplayAreaPen; //!< The outline color of the display areas.
+    QColor colorDisplayAreaBrush; //!< The fill colors of the display areas.
+    QColor colorDisplayAreaText; //!< The text color of the display areas.
 
-            QColor               colorDragHandles;       //!< The color used for the drag handles.
+    QColor colorDragHandles; //!< The color used for the drag handles.
 
-            QColor               colorSelectedAreaPen;   //!< The outline color of the selected area.
-            QColor               colorSelectedAreaBrush; //!< The fill color of the selected area.
-            QColor               colorSelectedAreaText;  //!< The text color of the selected area.
+    QColor colorSelectedAreaPen; //!< The outline color of the selected area.
+    QColor colorSelectedAreaBrush; //!< The fill color of the selected area.
+    QColor colorSelectedAreaText; //!< The text color of the selected area.
 
-            QFont                fontCaptions;           //!< The font used for all captions.
+    QFont fontCaptions; //!< The font used for all captions.
 
-            AreaSelectionWidget::DragMode dragMode;      //!< The current dragging mode if any.
-            QPoint               dragPoint;              //!< The last mouse position while dragging the selected area.
+    AreaSelectionWidget::DragMode dragMode; //!< The current dragging mode if any.
+    QPoint dragPoint; //!< The last mouse position while dragging the selected area.
 
-            QSize                widgetTargetSize;       //!< The size of the widget we want, if possible.
+    QSize widgetTargetSize; //!< The size of the widget we want, if possible.
 
-            qreal                outOfBoundsMargin;      //!< The out of bounds margin as set by the user.
-            qreal                outOfBoundsVirtualAreaMargin; //!< The number of real pixels (or a percentage) the user may drag the selected area outside of the virtual area.
-            qreal                outOfBoundsDisplayAreaMargin; //!< The number of widget pixels which are calculated from the oob virtual area margin.
+    qreal outOfBoundsMargin; //!< The out of bounds margin as set by the user.
+    qreal outOfBoundsVirtualAreaMargin; //!< The number of real pixels (or a percentage) the user may drag the selected area outside of the virtual area.
+    qreal outOfBoundsDisplayAreaMargin; //!< The number of widget pixels which are calculated from the oob virtual area margin.
 
-            qreal                scaleFactor;             //!< The scale factor which scales the virtual area's size to the widget's display area size.
+    qreal scaleFactor; //!< The scale factor which scales the virtual area's size to the widget's display area size.
 
-            QMap<QString, QRect> areaRectsList;           //!< The list of area rectangles which form the virtual area in real size.
-            QStringList          areaCaptionsList;        //!< The list of captions for each area.
+    QMap<QString, QRect> areaRectsList; //!< The list of area rectangles which form the virtual area in real size.
+    QStringList areaCaptionsList; //!< The list of captions for each area.
 
-            QRect                rectVirtualArea;         //!< The rectangle which holds the virtual area in real size.
+    QRect rectVirtualArea; //!< The rectangle which holds the virtual area in real size.
 
-            QRectF               rectDisplayArea;         //!< The rectangle which holds the scaled virtual area displayed to the user.
-            QList<QRectF>        rectDisplayAreas;        //!< The list of scaled sub-areas which make up the display area.
-            QRectF               rectSelectedArea;        //!< The rectangle which holds the size and position of the selected display area.
+    QRectF rectDisplayArea; //!< The rectangle which holds the scaled virtual area displayed to the user.
+    QList<QRectF> rectDisplayAreas; //!< The list of scaled sub-areas which make up the display area.
+    QRectF rectSelectedArea; //!< The rectangle which holds the size and position of the selected display area.
 
-            QRect                rectDragHandleTop;       //!< The rectangle which holds the size and position of the top drag handle.
-            QRect                rectDragHandleRight;     //!< The rectangle which holds the size and position of the right drag handle.
-            QRect                rectDragHandleBottom;    //!< The rectangle which holds the size and position of the bottom drag handle.
-            QRect                rectDragHandleLeft;      //!< The rectangle which holds the size and position of the top drag handle.
+    QRect rectDragHandleTop; //!< The rectangle which holds the size and position of the top drag handle.
+    QRect rectDragHandleRight; //!< The rectangle which holds the size and position of the right drag handle.
+    QRect rectDragHandleBottom; //!< The rectangle which holds the size and position of the bottom drag handle.
+    QRect rectDragHandleLeft; //!< The rectangle which holds the size and position of the top drag handle.
 
-            qreal                proportions = 1;
-            bool                 proportionsLocked = false;
-    }; // PRIVATE CLASS
+    qreal proportions = 1;
+    bool proportionsLocked = false;
+}; // PRIVATE CLASS
 
-    const qreal AreaSelectionWidgetPrivate::DISPLAY_AREA_EXTRA_MARGIN = 5.;
-    const qreal AreaSelectionWidgetPrivate::DRAG_HANDLE_SIZE          = 6.;
+const qreal AreaSelectionWidgetPrivate::DISPLAY_AREA_EXTRA_MARGIN = 5.;
+const qreal AreaSelectionWidgetPrivate::DRAG_HANDLE_SIZE = 6.;
 
 } // NAMESPACE
 
-
-AreaSelectionWidget::AreaSelectionWidget(QWidget* parent)
-        : QWidget(parent), d_ptr(new AreaSelectionWidgetPrivate)
+AreaSelectionWidget::AreaSelectionWidget(QWidget *parent)
+    : QWidget(parent)
+    , d_ptr(new AreaSelectionWidgetPrivate)
 {
 }
 
-
 AreaSelectionWidget::~AreaSelectionWidget()
 {
     delete this->d_ptr;
 }
 
-
 void AreaSelectionWidget::clearSelection()
 {
     Q_D(const AreaSelectionWidget);
@@ -135,7 +134,6 @@ void AreaSelectionWidget::clearSelection()
     setSelection(d->rectVirtualArea, true);
 }
 
-
 const QRect AreaSelectionWidget::getSelection() const
 {
     Q_D(const AreaSelectionWidget);
@@ -143,26 +141,23 @@ const QRect AreaSelectionWidget::getSelection() const
     return calculateUnscaledArea(d->rectSelectedArea, d->scaleFactor, getTotalDisplayAreaMargin());
 }
 
-
 const QString AreaSelectionWidget::getSelectionAsString() const
 {
     QRect area = getSelection();
     return QString::fromLatin1("%1 %2 %3 %4").arg(area.x()).arg(area.y()).arg(area.width()).arg(area.height());
 }
 
-
-const QRect& AreaSelectionWidget::getVirtualArea() const
+const QRect &AreaSelectionWidget::getVirtualArea() const
 {
     Q_D(const AreaSelectionWidget);
 
     return d->rectVirtualArea;
 }
 
-
-void AreaSelectionWidget::setArea(const QRect& area, const QString& caption)
+void AreaSelectionWidget::setArea(const QRect &area, const QString &caption)
 {
     QMap<QString, QRect> areaList;
-    QStringList    captionList;
+    QStringList captionList;
 
     areaList[caption] = area;
     captionList.append(caption);
@@ -170,17 +165,15 @@ void AreaSelectionWidget::setArea(const QRect& area, const QString& caption)
     setAreas(areaList, captionList);
 }
 
-
 void AreaSelectionWidget::setAreas(const QMap<QString, QRect> &areas, const QStringList &areaCaptions)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
-    d->areaRectsList     = areas;
-    d->areaCaptionsList  = areaCaptions;
+    d->areaRectsList = areas;
+    d->areaCaptionsList = areaCaptions;
     setupWidget();
 }
 
-
 void AreaSelectionWidget::setDrawAreaCaptions(bool value)
 {
     Q_D(AreaSelectionWidget);
@@ -188,7 +181,6 @@ void AreaSelectionWidget::setDrawAreaCaptions(bool value)
     d->drawAreaCaption = value;
 }
 
-
 void AreaSelectionWidget::setDrawSelectionCaption(bool value)
 {
     Q_D(AreaSelectionWidget);
@@ -196,15 +188,13 @@ void AreaSelectionWidget::setDrawSelectionCaption(bool value)
     d->drawSelectionCaption = value;
 }
 
-
-void AreaSelectionWidget::setFont(const QFont& font)
+void AreaSelectionWidget::setFont(const QFont &font)
 {
     Q_D(AreaSelectionWidget);
 
     d->fontCaptions = font;
 }
 
-
 void AreaSelectionWidget::setOutOfBoundsMargin(qreal margin)
 {
     Q_D(AreaSelectionWidget);
@@ -217,8 +207,7 @@ void AreaSelectionWidget::setOutOfBoundsMargin(qreal margin)
     setupWidget();
 }
 
-
-void AreaSelectionWidget::setSelection(const QRect& selection, bool emitUpdate)
+void AreaSelectionWidget::setSelection(const QRect &selection, bool emitUpdate)
 {
     Q_D(AreaSelectionWidget);
 
@@ -230,8 +219,7 @@ void AreaSelectionWidget::setSelection(const QRect& selection, bool emitUpdate)
     // if every value is -1 then the user wants to set the selection to the maximum
     QRect newSelection = selection;
 
-    if (!selection.isValid() ||
-        (selection.x() == -1 && selection.y() == -1 && selection.width() == -1 && selection.height() == -1)) {
+    if (!selection.isValid() || (selection.x() == -1 && selection.y() == -1 && selection.width() == -1 && selection.height() == -1)) {
         newSelection = d->rectVirtualArea;
     }
 
@@ -251,7 +239,6 @@ void AreaSelectionWidget::setSelection(const QRect& selection, bool emitUpdate)
     }
 }
 
-
 void AreaSelectionWidget::setSelection(QString output)
 {
     Q_D(const AreaSelectionWidget);
@@ -265,9 +252,7 @@ void AreaSelectionWidget::setSelection(QString output)
     setSelection(*areaRect, true);
 }
 
-
-
-void AreaSelectionWidget::setWidgetTargetSize(const QSize& size)
+void AreaSelectionWidget::setWidgetTargetSize(const QSize &size)
 {
     Q_D(AreaSelectionWidget);
 
@@ -289,8 +274,7 @@ void AreaSelectionWidget::lockProportions(bool enable)
     }
 }
 
-
-void AreaSelectionWidget::mouseMoveEvent(QMouseEvent* event)
+void AreaSelectionWidget::mouseMoveEvent(QMouseEvent *event)
 {
     Q_D(AreaSelectionWidget);
 
@@ -306,10 +290,9 @@ void AreaSelectionWidget::mouseMoveEvent(QMouseEvent* event)
     QWidget::update();
 }
 
-
-void AreaSelectionWidget::mousePressEvent(QMouseEvent* event)
+void AreaSelectionWidget::mousePressEvent(QMouseEvent *event)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     // do nothing if we do not have areas set or if the user is already dragging
     if (d->areaRectsList.isEmpty() || isUserDragging()) {
@@ -319,7 +302,7 @@ void AreaSelectionWidget::mousePressEvent(QMouseEvent* event)
     // determine what the user wants to drag - a handle or the whole selected area
     const QPoint mousePosition(event->pos());
 
-    if (d->rectDragHandleTop.contains(mousePosition)){
+    if (d->rectDragHandleTop.contains(mousePosition)) {
         d->dragMode = AreaSelectionWidget::DragMode::DragTopHandle;
 
     } else if (d->rectDragHandleRight.contains(mousePosition)) {
@@ -332,7 +315,7 @@ void AreaSelectionWidget::mousePressEvent(QMouseEvent* event)
         d->dragMode = AreaSelectionWidget::DragMode::DragLeftHandle;
 
     } else if (d->rectSelectedArea.contains(mousePosition)) {
-        d->dragMode  = AreaSelectionWidget::DragMode::DragSelectedArea;
+        d->dragMode = AreaSelectionWidget::DragMode::DragSelectedArea;
         d->dragPoint = mousePosition;
 
         QWidget::setCursor(Qt::SizeAllCursor);
@@ -343,8 +326,7 @@ void AreaSelectionWidget::mousePressEvent(QMouseEvent* event)
     }
 }
 
-
-void AreaSelectionWidget::mouseReleaseEvent(QMouseEvent* event)
+void AreaSelectionWidget::mouseReleaseEvent(QMouseEvent *event)
 {
     Q_D(AreaSelectionWidget);
     Q_UNUSED(event);
@@ -362,8 +344,7 @@ void AreaSelectionWidget::mouseReleaseEvent(QMouseEvent* event)
     }
 }
 
-
-void AreaSelectionWidget::paintEvent(QPaintEvent* event)
+void AreaSelectionWidget::paintEvent(QPaintEvent *event)
 {
     Q_D(AreaSelectionWidget);
     Q_UNUSED(event);
@@ -374,8 +355,8 @@ void AreaSelectionWidget::paintEvent(QPaintEvent* event)
         return;
     }
 
-    QPainter painter( this );
-    painter.setRenderHint( QPainter::Antialiasing );
+    QPainter painter(this);
+    painter.setRenderHint(QPainter::Antialiasing);
 
     paintDisplayAreas(painter, false);
     paintSelectedArea(painter, false);
@@ -394,8 +375,7 @@ void AreaSelectionWidget::paintEvent(QPaintEvent* event)
     }
 }
 
-
-const QRectF AreaSelectionWidget::calculateDisplayArea(const QRect& virtualArea, qreal scaleFactor, qreal totalDisplayAreaMargin) const
+const QRectF AreaSelectionWidget::calculateDisplayArea(const QRect &virtualArea, qreal scaleFactor, qreal totalDisplayAreaMargin) const
 {
     QRectF displayArea;
 
@@ -407,11 +387,10 @@ const QRectF AreaSelectionWidget::calculateDisplayArea(const QRect& virtualArea,
     return displayArea;
 }
 
-
-const QList< QRectF > AreaSelectionWidget::calculateDisplayAreas(const QMap<QString, QRect> areas, qreal scaleFactor, qreal totalDisplayAreaMargin) const
+const QList<QRectF> AreaSelectionWidget::calculateDisplayAreas(const QMap<QString, QRect> areas, qreal scaleFactor, qreal totalDisplayAreaMargin) const
 {
     QList<QRectF> displayAreas;
-    QRectF        displayArea;
+    QRectF displayArea;
 
     foreach (QRect area, areas.values()) {
         displayArea = calculateScaledArea(area, scaleFactor, totalDisplayAreaMargin);
@@ -421,8 +400,7 @@ const QList< QRectF > AreaSelectionWidget::calculateDisplayAreas(const QMap<QStr
     return displayAreas;
 }
 
-
-qreal AreaSelectionWidget::calculateOutOfBoundsVirtualAreaMargin(const QRect& virtualArea, qreal outOfBoundsMargin) const
+qreal AreaSelectionWidget::calculateOutOfBoundsVirtualAreaMargin(const QRect &virtualArea, qreal outOfBoundsMargin) const
 {
     if (!virtualArea.isValid() || outOfBoundsMargin < 0.) {
         return 0.;
@@ -442,8 +420,10 @@ qreal AreaSelectionWidget::calculateOutOfBoundsVirtualAreaMargin(const QRect& vi
     return margin;
 }
 
-
-qreal AreaSelectionWidget::calculateScaleFactor(const QSize& targetSize, const QRect& virtualArea, qreal virtualAreaOutOfBoundsMargin, qreal displayAreaExtraMargin) const
+qreal AreaSelectionWidget::calculateScaleFactor(const QSize &targetSize,
+                                                const QRect &virtualArea,
+                                                qreal virtualAreaOutOfBoundsMargin,
+                                                qreal displayAreaExtraMargin) const
 {
     qreal scaleFactor = 0.1; // default is 10% to prevent a division by zero
 
@@ -461,8 +441,7 @@ qreal AreaSelectionWidget::calculateScaleFactor(const QSize& targetSize, const Q
     return scaleFactor;
 }
 
-
-const QRectF AreaSelectionWidget::calculateScaledArea(const QRect& area, qreal scaleFactor, qreal totalDisplayAreaMargin) const
+const QRectF AreaSelectionWidget::calculateScaledArea(const QRect &area, qreal scaleFactor, qreal totalDisplayAreaMargin) const
 {
     QRectF scaledArea;
 
@@ -474,8 +453,7 @@ const QRectF AreaSelectionWidget::calculateScaledArea(const QRect& area, qreal s
     return scaledArea;
 }
 
-
-const QRect AreaSelectionWidget::calculateUnscaledArea(const QRectF& area, qreal scaleFactor, qreal totalDisplayAreaMargin) const
+const QRect AreaSelectionWidget::calculateUnscaledArea(const QRectF &area, qreal scaleFactor, qreal totalDisplayAreaMargin) const
 {
     QRect unscaledArea;
 
@@ -487,7 +465,6 @@ const QRect AreaSelectionWidget::calculateUnscaledArea(const QRectF& area, qreal
     return unscaledArea;
 }
 
-
 const QRect AreaSelectionWidget::calculateVirtualArea(const QMap<QString, QRect> &areas) const
 {
     QRect virtualArea;
@@ -499,7 +476,6 @@ const QRect AreaSelectionWidget::calculateVirtualArea(const QMap<QString, QRect>
     return virtualArea;
 }
 
-
 qreal AreaSelectionWidget::getTotalDisplayAreaMargin() const
 {
     Q_D(const AreaSelectionWidget);
@@ -507,7 +483,6 @@ qreal AreaSelectionWidget::getTotalDisplayAreaMargin() const
     return (d->outOfBoundsDisplayAreaMargin + d->DISPLAY_AREA_EXTRA_MARGIN);
 }
 
-
 bool AreaSelectionWidget::isUserDragging() const
 {
     Q_D(const AreaSelectionWidget);
@@ -515,23 +490,22 @@ bool AreaSelectionWidget::isUserDragging() const
     return (d->dragMode != AreaSelectionWidget::DragMode::DragNone);
 }
 
-
-void AreaSelectionWidget::paintDisplayAreaCaptions(QPainter& painter)
+void AreaSelectionWidget::paintDisplayAreaCaptions(QPainter &painter)
 {
     Q_D(AreaSelectionWidget);
 
-    QRectF       area;
-    QString      caption;
-    qreal        captionX;
-    qreal        captionY;
+    QRectF area;
+    QString caption;
+    qreal captionX;
+    qreal captionY;
     QFontMetrics fontMetrics(d->fontCaptions);
 
-    painter.setPen( d->colorDisplayAreaText );
-    painter.setBrush( d->colorDisplayAreaText );
+    painter.setPen(d->colorDisplayAreaText);
+    painter.setBrush(d->colorDisplayAreaText);
     painter.setFont(d->fontCaptions);
 
-    for (int i = 0 ; i < d->rectDisplayAreas.size() ; ++i) {
-        area    = d->rectDisplayAreas.at(i);
+    for (int i = 0; i < d->rectDisplayAreas.size(); ++i) {
+        area = d->rectDisplayAreas.at(i);
         caption = (d->areaCaptionsList.size() > i) ? d->areaCaptionsList.at(i) : QString();
 
         if (!caption.isEmpty() && area.isValid()) {
@@ -543,23 +517,22 @@ void AreaSelectionWidget::paintDisplayAreaCaptions(QPainter& painter)
     }
 }
 
-
-void AreaSelectionWidget::paintDisplayAreas(QPainter& painter, bool outlineOnly)
+void AreaSelectionWidget::paintDisplayAreas(QPainter &painter, bool outlineOnly)
 {
     Q_D(AreaSelectionWidget);
 
     // paint the whole display area
-    painter.setPen( d->colorDisplayAreaPen );
-    painter.setBrush( outlineOnly ? Qt::transparent : d->colorDisplayAreaBrush );
+    painter.setPen(d->colorDisplayAreaPen);
+    painter.setBrush(outlineOnly ? Qt::transparent : d->colorDisplayAreaBrush);
 
     if (d->rectDisplayAreas.size() > 1) {
-        painter.drawRect( d->rectDisplayArea );
+        painter.drawRect(d->rectDisplayArea);
     }
 
     // paint the display sub areas and captions
     QRectF area;
 
-    for (int i = 0 ; i < d->rectDisplayAreas.size() ; ++i) {
+    for (int i = 0; i < d->rectDisplayAreas.size(); ++i) {
         area = d->rectDisplayAreas.at(i);
 
         if (area.isValid()) {
@@ -568,15 +541,14 @@ void AreaSelectionWidget::paintDisplayAreas(QPainter& painter, bool outlineOnly)
     }
 }
 
-
-void AreaSelectionWidget::paintDragHandles(QPainter& painter)
+void AreaSelectionWidget::paintDragHandles(QPainter &painter)
 {
     Q_D(AreaSelectionWidget);
 
     QColor color("#326583");
 
-    painter.setPen( d->colorSelectedAreaPen );
-    painter.setBrush( d->colorSelectedAreaPen );
+    painter.setPen(d->colorSelectedAreaPen);
+    painter.setBrush(d->colorSelectedAreaPen);
 
     painter.drawRect(d->rectDragHandleTop);
     painter.drawRect(d->rectDragHandleRight);
@@ -584,18 +556,16 @@ void AreaSelectionWidget::paintDragHandles(QPainter& painter)
     painter.drawRect(d->rectDragHandleLeft);
 }
 
-
-void AreaSelectionWidget::paintSelectedArea(QPainter& painter, bool outlineOnly)
+void AreaSelectionWidget::paintSelectedArea(QPainter &painter, bool outlineOnly)
 {
     Q_D(AreaSelectionWidget);
 
-    painter.setPen( d->colorSelectedAreaPen );
+    painter.setPen(d->colorSelectedAreaPen);
     painter.setBrush(outlineOnly ? Qt::transparent : d->colorSelectedAreaBrush);
-    painter.drawRect( d->rectSelectedArea );
+    painter.drawRect(d->rectSelectedArea);
 }
 
-
-void AreaSelectionWidget::paintSelectedAreaCaption(QPainter& painter)
+void AreaSelectionWidget::paintSelectedAreaCaption(QPainter &painter)
 {
     Q_D(AreaSelectionWidget);
 
@@ -607,11 +577,7 @@ void AreaSelectionWidget::paintSelectedAreaCaption(QPainter& painter)
 
     QRect selectedArea = getSelection();
 
-    QString text = QString::fromLatin1("%1x%2+%3+%4")
-                            .arg(selectedArea.width())
-                            .arg(selectedArea.height())
-                            .arg(selectedArea.x())
-                            .arg(selectedArea.y());
+    QString text = QString::fromLatin1("%1x%2+%3+%4").arg(selectedArea.width()).arg(selectedArea.height()).arg(selectedArea.x()).arg(selectedArea.y());
 
     qreal textX = d->rectDisplayArea.x() + (qreal)d->rectDisplayArea.width() / 2 - (qreal)fontMetrics.horizontalAdvance(text) / 2;
     qreal textY;
@@ -630,13 +596,9 @@ void AreaSelectionWidget::paintSelectedAreaCaption(QPainter& painter)
         }
     }
 
-
-
     painter.drawText(qRound(textX), qRound(textY), text);
 }
 
-
-
 void AreaSelectionWidget::setupWidget()
 {
     Q_D(AreaSelectionWidget);
@@ -647,20 +609,20 @@ void AreaSelectionWidget::setupWidget()
     }
 
     // calculate transformation data
-    d->rectVirtualArea              = calculateVirtualArea(d->areaRectsList);
+    d->rectVirtualArea = calculateVirtualArea(d->areaRectsList);
     d->outOfBoundsVirtualAreaMargin = calculateOutOfBoundsVirtualAreaMargin(d->rectVirtualArea, d->outOfBoundsMargin);
-    d->scaleFactor                  = calculateScaleFactor(!d->widgetTargetSize.isEmpty() ? d->widgetTargetSize : size(),
-                                                           d->rectVirtualArea,
-                                                           d->outOfBoundsVirtualAreaMargin,
-                                                           d->DISPLAY_AREA_EXTRA_MARGIN);
+    d->scaleFactor = calculateScaleFactor(!d->widgetTargetSize.isEmpty() ? d->widgetTargetSize : size(),
+                                          d->rectVirtualArea,
+                                          d->outOfBoundsVirtualAreaMargin,
+                                          d->DISPLAY_AREA_EXTRA_MARGIN);
     d->outOfBoundsDisplayAreaMargin = d->outOfBoundsVirtualAreaMargin * d->scaleFactor;
-    d->rectDisplayArea              = calculateDisplayArea(d->rectVirtualArea, d->scaleFactor, getTotalDisplayAreaMargin());
-    d->rectDisplayAreas             = calculateDisplayAreas(d->areaRectsList, d->scaleFactor, getTotalDisplayAreaMargin());
+    d->rectDisplayArea = calculateDisplayArea(d->rectVirtualArea, d->scaleFactor, getTotalDisplayAreaMargin());
+    d->rectDisplayAreas = calculateDisplayAreas(d->areaRectsList, d->scaleFactor, getTotalDisplayAreaMargin());
 
     // setup widget
-    QWidget::setMouseTracking( true );
+    QWidget::setMouseTracking(true);
 
-    qreal widgetWidth  = d->rectDisplayArea.width() + 2. * getTotalDisplayAreaMargin();
+    qreal widgetWidth = d->rectDisplayArea.width() + 2. * getTotalDisplayAreaMargin();
     qreal widgetHeight = d->rectDisplayArea.height() + 2. * getTotalDisplayAreaMargin();
 
     QWidget::setMinimumSize(widgetWidth, widgetHeight);
@@ -673,21 +635,20 @@ void AreaSelectionWidget::setupWidget()
     updateDragHandles();
 }
 
-
 void AreaSelectionWidget::updateDragHandles()
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     // the size of the drag handles
-    static const qreal handleSize     = d->DRAG_HANDLE_SIZE;
+    static const qreal handleSize = d->DRAG_HANDLE_SIZE;
     static const qreal handleSizeHalf = handleSize / 2.;
 
     // some convenience vars so we have to type less
-    const qreal areaX     = d->rectSelectedArea.x();
-    const qreal areaY     = d->rectSelectedArea.y();
-    const qreal areaW     = d->rectSelectedArea.width();
+    const qreal areaX = d->rectSelectedArea.x();
+    const qreal areaY = d->rectSelectedArea.y();
+    const qreal areaW = d->rectSelectedArea.width();
     const qreal areaWHalf = areaW / 2.;
-    const qreal areaH     = d->rectSelectedArea.height();
+    const qreal areaH = d->rectSelectedArea.height();
     const qreal areaHHalf = areaH / 2.;
 
     d->rectDragHandleTop.setX(areaX + areaWHalf - handleSizeHalf);
@@ -711,8 +672,7 @@ void AreaSelectionWidget::updateDragHandles()
     d->rectDragHandleLeft.setHeight(handleSize);
 }
 
-
-void AreaSelectionWidget::updateMouseCursor(const QPoint& mousePosition)
+void AreaSelectionWidget::updateMouseCursor(const QPoint &mousePosition)
 {
     Q_D(AreaSelectionWidget);
 
@@ -722,23 +682,21 @@ void AreaSelectionWidget::updateMouseCursor(const QPoint& mousePosition)
     }
 
     if (d->rectDragHandleLeft.contains(mousePosition) || d->rectDragHandleRight.contains(mousePosition)) {
-        QWidget::setCursor( Qt::SizeHorCursor );
+        QWidget::setCursor(Qt::SizeHorCursor);
 
     } else if (d->rectDragHandleTop.contains(mousePosition) || d->rectDragHandleBottom.contains(mousePosition)) {
-        QWidget::setCursor( Qt::SizeVerCursor );
+        QWidget::setCursor(Qt::SizeVerCursor);
 
     } else {
-        QWidget::setCursor( Qt::ArrowCursor );
+        QWidget::setCursor(Qt::ArrowCursor);
     }
 }
 
-
-void AreaSelectionWidget::updateSelectedAreaOnDrag(const QPoint& mousePosition)
+void AreaSelectionWidget::updateSelectedAreaOnDrag(const QPoint &mousePosition)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     switch (d->dragMode) {
-
     case DragMode::DragNone:
         break;
 
@@ -764,25 +722,24 @@ void AreaSelectionWidget::updateSelectedAreaOnDrag(const QPoint& mousePosition)
     }
 }
 
-
-void AreaSelectionWidget::updateSelectedAreaOnDragArea(const QPoint& mousePosition)
+void AreaSelectionWidget::updateSelectedAreaOnDragArea(const QPoint &mousePosition)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     const qreal dragXOffset = mousePosition.x() - d->dragPoint.x();
     const qreal dragYOffset = mousePosition.y() - d->dragPoint.y();
 
-    const qreal leftBound   = d->rectDisplayArea.x() - d->outOfBoundsDisplayAreaMargin;
-    const qreal rightBound  = d->rectDisplayArea.x() + d->rectDisplayArea.width() + d->outOfBoundsDisplayAreaMargin - d->rectSelectedArea.width();
-    const qreal topBound    = d->rectDisplayArea.y() - d->outOfBoundsDisplayAreaMargin;
+    const qreal leftBound = d->rectDisplayArea.x() - d->outOfBoundsDisplayAreaMargin;
+    const qreal rightBound = d->rectDisplayArea.x() + d->rectDisplayArea.width() + d->outOfBoundsDisplayAreaMargin - d->rectSelectedArea.width();
+    const qreal topBound = d->rectDisplayArea.y() - d->outOfBoundsDisplayAreaMargin;
     const qreal bottomBound = d->rectDisplayArea.y() + d->rectDisplayArea.height() + d->outOfBoundsDisplayAreaMargin - d->rectSelectedArea.height();
 
     const qreal oldW = d->rectSelectedArea.width();
     const qreal oldH = d->rectSelectedArea.height();
     const qreal oldX = d->rectSelectedArea.x();
     const qreal oldY = d->rectSelectedArea.y();
-    qreal       newX = oldX + dragXOffset;
-    qreal       newY = oldY + dragYOffset;
+    qreal newX = oldX + dragXOffset;
+    qreal newY = oldY + dragYOffset;
 
     // use old values if the new ones are out of bounds
     if (newX < leftBound || rightBound < newX) {
@@ -805,17 +762,16 @@ void AreaSelectionWidget::updateSelectedAreaOnDragArea(const QPoint& mousePositi
     updateSelectedAreaSize(false);
 }
 
-
-void AreaSelectionWidget::updateSelectedAreaOnDragBottom(const QPoint& mousePosition)
+void AreaSelectionWidget::updateSelectedAreaOnDragBottom(const QPoint &mousePosition)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     // the drag handle size in the bounds calculations ensure that the
     // box does not get too small to reach the drag handles with the mouse
-    const qreal topBound    = d->rectSelectedArea.y() + d->DRAG_HANDLE_SIZE;
+    const qreal topBound = d->rectSelectedArea.y() + d->DRAG_HANDLE_SIZE;
     const qreal bottomBound = d->rectDisplayArea.y() + d->rectDisplayArea.height() + d->outOfBoundsDisplayAreaMargin;
-    const qreal mouseY      = mousePosition.y();
-    qreal       newHeight   = 0.;
+    const qreal mouseY = mousePosition.y();
+    qreal newHeight = 0.;
 
     if (mouseY < topBound) {
         newHeight = topBound - d->rectSelectedArea.y();
@@ -827,7 +783,8 @@ void AreaSelectionWidget::updateSelectedAreaOnDragBottom(const QPoint& mousePosi
 
     if (d->proportionsLocked) {
         const auto newWidth = newHeight * d->proportions;
-        if (newWidth < topBound || newWidth > bottomBound) return;
+        if (newWidth < topBound || newWidth > bottomBound)
+            return;
         d->rectSelectedArea.setWidth(newWidth);
     }
     d->rectSelectedArea.setHeight(newHeight);
@@ -835,17 +792,16 @@ void AreaSelectionWidget::updateSelectedAreaOnDragBottom(const QPoint& mousePosi
     updateSelectedAreaSize(true);
 }
 
-
-void AreaSelectionWidget::updateSelectedAreaOnDragLeft(const QPoint& mousePosition)
+void AreaSelectionWidget::updateSelectedAreaOnDragLeft(const QPoint &mousePosition)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     // the drag handle size in the bounds calculations ensure that the
     // box does not get too small to reach the drag handles with the mouse
-    const qreal leftBound  = d->rectDisplayArea.x() - d->outOfBoundsDisplayAreaMargin;
+    const qreal leftBound = d->rectDisplayArea.x() - d->outOfBoundsDisplayAreaMargin;
     const qreal rightBound = d->rectSelectedArea.x() + d->rectSelectedArea.width() - d->DRAG_HANDLE_SIZE;
-    const qreal mouseX     = mousePosition.x();
-    qreal       newX       = 0.;
+    const qreal mouseX = mousePosition.x();
+    qreal newX = 0.;
 
     if (mouseX < leftBound) {
         newX = leftBound;
@@ -857,7 +813,8 @@ void AreaSelectionWidget::updateSelectedAreaOnDragLeft(const QPoint& mousePositi
 
     if (d->proportionsLocked) {
         const auto newY = d->rectSelectedArea.y() + (newX - d->rectSelectedArea.x()) / d->proportions;
-        if (newY < leftBound || newY > rightBound) return;
+        if (newY < leftBound || newY > rightBound)
+            return;
         d->rectSelectedArea.setY(newY);
     }
     d->rectSelectedArea.setX(newX);
@@ -865,17 +822,16 @@ void AreaSelectionWidget::updateSelectedAreaOnDragLeft(const QPoint& mousePositi
     updateSelectedAreaSize(false);
 }
 
-
-void AreaSelectionWidget::updateSelectedAreaOnDragRight(const QPoint& mousePosition)
+void AreaSelectionWidget::updateSelectedAreaOnDragRight(const QPoint &mousePosition)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     // the drag handle size in the bounds calculations ensure that the
     // box does not get too small to reach the drag handles with the mouse
-    const qreal leftBound  = d->rectSelectedArea.x() + d->DRAG_HANDLE_SIZE;
+    const qreal leftBound = d->rectSelectedArea.x() + d->DRAG_HANDLE_SIZE;
     const qreal rightBound = d->rectDisplayArea.x() + d->rectDisplayArea.width() + d->outOfBoundsDisplayAreaMargin;
-    const qreal mouseX     = mousePosition.x();
-    qreal       newWidth   = 0.;
+    const qreal mouseX = mousePosition.x();
+    qreal newWidth = 0.;
 
     if (mouseX < leftBound) {
         newWidth = leftBound - d->rectSelectedArea.x();
@@ -887,7 +843,8 @@ void AreaSelectionWidget::updateSelectedAreaOnDragRight(const QPoint& mousePosit
 
     if (d->proportionsLocked) {
         const auto newHeight = newWidth / d->proportions;
-        if (newHeight < leftBound || newHeight > rightBound) return;
+        if (newHeight < leftBound || newHeight > rightBound)
+            return;
         d->rectSelectedArea.setHeight(newWidth / d->proportions);
     }
     d->rectSelectedArea.setWidth(newWidth);
@@ -895,17 +852,16 @@ void AreaSelectionWidget::updateSelectedAreaOnDragRight(const QPoint& mousePosit
     updateSelectedAreaSize(true);
 }
 
-
-void AreaSelectionWidget::updateSelectedAreaOnDragTop(const QPoint& mousePosition)
+void AreaSelectionWidget::updateSelectedAreaOnDragTop(const QPoint &mousePosition)
 {
-    Q_D (AreaSelectionWidget);
+    Q_D(AreaSelectionWidget);
 
     // the drag handle size in the bounds calculations ensure that the
     // box does not get too small to reach the drag handles with the mouse
-    const qreal topBound    = d->rectDisplayArea.y() - d->outOfBoundsDisplayAreaMargin;
+    const qreal topBound = d->rectDisplayArea.y() - d->outOfBoundsDisplayAreaMargin;
     const qreal bottomBound = d->rectSelectedArea.y() + d->rectSelectedArea.height() - d->DRAG_HANDLE_SIZE;
-    const qreal mouseY      = mousePosition.y();
-    qreal       newY        = 0.;
+    const qreal mouseY = mousePosition.y();
+    qreal newY = 0.;
 
     if (mouseY < topBound) {
         newY = topBound;
@@ -917,7 +873,8 @@ void AreaSelectionWidget::updateSelectedAreaOnDragTop(const QPoint& mousePositio
 
     if (d->proportionsLocked) {
         const auto newX = d->rectSelectedArea.x() + (newY - d->rectSelectedArea.y()) * d->proportions;
-        if (newX < topBound || newX > bottomBound) return;
+        if (newX < topBound || newX > bottomBound)
+            return;
         d->rectSelectedArea.setX(newX);
     }
     d->rectSelectedArea.setY(newY);
@@ -925,7 +882,6 @@ void AreaSelectionWidget::updateSelectedAreaOnDragTop(const QPoint& mousePositio
     updateSelectedAreaSize(false);
 }
 
-
 void AreaSelectionWidget::updateSelectedAreaSize(bool fixPositionInsteadOfSize)
 {
     Q_D(AreaSelectionWidget);
@@ -933,13 +889,12 @@ void AreaSelectionWidget::updateSelectedAreaSize(bool fixPositionInsteadOfSize)
     // the selected area might be too large but
     // we expect it to be within valid bounds
 
-    qreal selectedWidth  = d->rectSelectedArea.width();
+    qreal selectedWidth = d->rectSelectedArea.width();
     qreal selectedHeight = d->rectSelectedArea.height();
-    qreal displayWidth   = d->rectDisplayArea.width();
-    qreal displayHeight  = d->rectDisplayArea.height();
+    qreal displayWidth = d->rectDisplayArea.width();
+    qreal displayHeight = d->rectDisplayArea.height();
 
     if (selectedWidth > displayWidth) {
-
         if (fixPositionInsteadOfSize) {
             qreal newX = d->rectSelectedArea.x() + selectedWidth - displayWidth;
             d->rectSelectedArea.setX(newX);
@@ -950,7 +905,6 @@ void AreaSelectionWidget::updateSelectedAreaSize(bool fixPositionInsteadOfSize)
     }
 
     if (selectedHeight > displayHeight) {
-
         if (fixPositionInsteadOfSize) {
             qreal newY = d->rectSelectedArea.y() + selectedHeight - displayHeight;
             d->rectSelectedArea.setY(newY);
@@ -958,7 +912,6 @@ void AreaSelectionWidget::updateSelectedAreaSize(bool fixPositionInsteadOfSize)
         } else {
             d->rectSelectedArea.setHeight(displayHeight);
         }
-
     }
 }
 
